@@ -22,6 +22,7 @@ my $new_x;
 my $new_y;
 my $F;
 my $dev = 0;
+my $psize = 1;
 
 $file = 1 if ($arg =~ /file/i);    # File Handle drawing mode
 
@@ -102,6 +103,7 @@ $SIG{'INT'}  = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
 $F->wait_for_console(!$rpi);
 $F->cls('OFF');
 $F->splash($VERSION);
+
 sleep 1;
 # if (0) {
 color_mapping();
@@ -166,7 +168,7 @@ monochrome();
 or_drawing();
 xor_drawing();
 and_drawing();
-alpha_drawing(); # unless ($rpi);
+alpha_drawing();
 mask_drawing();
 unmask_drawing();
 animated();
@@ -240,7 +242,7 @@ sub plotting {
         my $x = int(rand($screen_width));
         my $y = int(rand($screen_height));
         $F->set_color({ 'alpha' => 255, 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->plot({ 'x' => $x, 'y' => $y });
+        $F->plot({ 'x' => $x, 'y' => $y, 'pixel_size' => $psize });
     } ## end while (time < $s)
 } ## end sub plotting
 
@@ -255,7 +257,8 @@ sub lines {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->line({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'antialiased' => $aa });
+        $F->line({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'antialiased' => $aa, 'pixel_size' => $psize });
+#        sleep 1 if ($aa);
     }
 } ## end sub lines
 
@@ -272,8 +275,8 @@ sub angle_lines {
     my $angle = 0;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => int($F->{'H_CLIP'} / 2), 'angle' => $angle, 'antialiased' => $aa });
-	    $angle += 1.1;
+        $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => int($F->{'H_CLIP'} / 2), 'angle' => $angle, 'antialiased' => $aa, 'pixel_size' => $psize });
+	    $angle += 7;
         $angle -= 360 if ($angle >= 360);
     } ## end while (time < $s)
 } ## end sub angle_lines
@@ -285,7 +288,7 @@ sub boxes {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)) });
+        $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'pixel_size' => $psize });
     }
 } ## end sub boxes
 
@@ -393,7 +396,7 @@ sub rounded_boxes {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16) });
+        $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'pixel_size' => $psize });
     }
 } ## end sub rounded_boxes
 
@@ -489,7 +492,7 @@ sub circles {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y) });
+        $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'pixel_size' => $psize });
     }
 } ## end sub circles
 
@@ -577,7 +580,7 @@ sub arcs {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360) });
+        $F->arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'pixel_size' => $psize });
     }
 } ## end sub arcs
 
@@ -587,7 +590,7 @@ sub poly_arcs {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->poly_arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360) });
+        $F->poly_arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'pixel_size' => $psize });
     }
 } ## end sub poly_arcs
 
@@ -679,7 +682,7 @@ sub ellipses {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y) });
+        $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'pixel_size' => $psize });
     }
 } ## end sub ellipses
 
@@ -771,7 +774,7 @@ sub polygons {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        my $points = int(rand(2)) + 3;
+        my $points = 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -779,7 +782,8 @@ sub polygons {
         $F->polygon(
             {
                 'coordinates' => $coords,
-                'antialiased' => $aa
+                'antialiased' => $aa,
+                'pixel_size'  => $psize
             }
         );
     }
@@ -792,7 +796,7 @@ sub filled_polygons {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        my $points = int(rand(2)) + 3;
+        my $points = 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -814,7 +818,7 @@ sub hatch_filled_polygons {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        my $points = int(rand(2)) + 3;
+        my $points = 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -840,7 +844,7 @@ sub gradient_polygons {
         my @red    = map { $_ = int(rand(256)) } (1 .. $count);
         my @green  = map { $_ = int(rand(256)) } (1 .. $count);
         my @blue   = map { $_ = int(rand(256)) } (1 .. $count);
-        my $points = int(rand(2)) + 3;
+        my $points = 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -869,7 +873,7 @@ sub texture_filled_polygons {
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
     while (time < $s) {
         my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-        my $points = int(rand(2)) + 3;
+        my $points = 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -895,7 +899,7 @@ sub beziers {
         foreach my $c (1 .. int(rand(20))) {
             push(@coords, int(rand($XX)), int(rand($YY)));
         }
-        $F->bezier({ 'coordinates' => \@coords, 'points' => 100 });
+        $F->bezier({ 'coordinates' => \@coords, 'points' => 100, 'pixel_size' => $psize });
     } ## end while (time < $s)
 } ## end sub beziers
 
@@ -1226,7 +1230,7 @@ sub monochrome {
 } ## end sub monochrome
 
 sub animated {
-    
+    $F->{'DIAGNOSTICS'} = 1;    
     print_it($F, 'Testing Animated Images.  Loading...', 'FFFF00FF');
     opendir(my $DIR, $images_path);
     chomp(my @list = readdir($DIR));
@@ -1239,6 +1243,7 @@ sub animated {
             
             if ($count || $XX <= 320) {
                 print_it($F, "Loading Animated Image '$info' Scaled to Full Screen", 'FFFF00FF');
+                print STDERR "\n";
                 $image = $F->load_image(
                     {
                         'width'  => $XX,
@@ -1249,6 +1254,7 @@ sub animated {
                 );
             } else {
                 print_it($F, "Loading Animated Image '$info' Native Size", 'FFFF00FF');
+                print STDERR "\n";
                 $image = $F->load_image(
                     {
                         'file'   => "$images_path/$info",
@@ -1260,16 +1266,16 @@ sub animated {
 
             foreach my $bench (0 .. 1) {
                 if ($count || $XX <= 320) {
-                    print_it($F, $bench ? "Testing Animated Image Display of '$info' Fullscreen Benchmark" : "Testing Animated Image Display of '$info' Fullscreen");
+                    print_it($F, $bench ? "Playing Animated Image of '$info' Fullscreen Benchmark" : "Playing Animated Image of '$info' Fullscreen",$bench ? '0066FFFF' : '00FF00FF');
                 } else {
-                    print_it($F, $bench ? "Testing Animated Image Display of '$info' Native Size Benchmark" : "Testing Animated Image Display of '$info' Native Size");
+                    print_it($F, $bench ? "Playing Animated Image of '$info' Native Size Benchmark" : "Playing Animated Image of '$info' Native Size",$bench ? '0066FFFF' : '00FF00FF');
                 }
                 if (defined($image)) {
                     $F->cls();
                     my $fps   = 0;
                     my $start = time;
                     my $s     = time + ($factor * 2);
-                    
+                    $F->mask_mode() if ($F->{'ACCELERATED'} && ! $F->{'FILE_MODE'});
                     while (time <= $s) {
                         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                             if (time > $s * 2) {
@@ -1286,7 +1292,7 @@ sub animated {
                             $fps++;
                             my $end = time - $start;
                             if ($end >= 1 && $bench) {
-                                print STDERR "\r", sprintf('%.02f FPS', (1 / $end) * $fps);
+                                print STDERR "\r", sprintf('%.03f FPS', (1 / $end) * $fps);
                                 $|     = 1;
                                 $fps   = 0;
                                 $start = time;
